
# Before running the code, make sure all packages are downloaded, and a working 
# directory is defined

# Downloading the astrochron and DecomposeR packages will be enough to download 
# the others

library(astrochron)
library(tictoc)
library(DecomposeR)
library(StratigrapheR)

# Please set a working directory ----

setwd("C:/Users/Seb/Desktop/Publications/1. EMD/ODP 926 Ceara Rise/treat")

# ----

sol <- La04_pre_obl_5_9

sol$spre <- (sol$pre - mean(sol$pre))/sd(sol$pre)
sol$sobl <- (sol$obl - mean(sol$obl))/sd(sol$obl)

sol$tar <- sol$spre - 0.5*sol$sobl

# Solution for amplitude modulation of precession ----

d2 <- La04_pre_0_20

dt2 <- d2$age
xy2 <- d2$xy - mean(d2$xy)

norm <- normalise(m = xy2, dt = dt2)

amp <- norm$a - mean(norm$a)

# ----

fil1 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/160, fhigh = 1/70, genplot = F)

fil2 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/526, fhigh = 1/285, genplot = F)

fil3 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/1400, fhigh = 1/800, genplot = F)

fil4 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/2000, fhigh = 1/3000, genplot = F)

resi <- as.numeric(amp - fil1$X1 - fil2$X1 - fil3$X1 - fil4$X1)

mi <- as.matrix(cbind(fil1$X1, fil2$X1, fil3$X1, fil4$X1))

ampe <- as.emd(xy = amp, dt = dt2, 
               imf = mi, res = resi)

plot_emd(ampe, track = F, name = "Precession Amplitude 2",
         # adapt.axis = T,
         s = list(type = "l", lwd = 2),
         i = list(type = "l", lwd = 2) #, dtlim = c(9000, 5000)
)

check.emd(ampe, xy = amp)

# ----

set.seed(43)

# ----

# z13

# w17

z13.e <- z13[-which(duplicated(z13$dt)),]

ref1 <- seq(5000, 7000,10)

ref2 <- seq(7000, 9000,10)

ref1.y <- approx(x = w17$age, y = w17$dt, xout = ref1)$y
ref2.y <- approx(x = w17$age, y = w17$dt, xout = ref2)$y

ref1.min <- every_nth(ref1.y, 10, empty = F)
ref1.maj <- every_nth(ref1.y, 10, empty = F, inv = T)

ref2.min <- every_nth(ref2.y, 10, empty = F)
ref2.maj <- every_nth(ref2.y, 10, empty = F, inv = T)

ref2.maj[length(ref2.maj)] <- 225.3700

g1 <- function()
{
  
  par(yaxs = "i", mfrow = c(1,4))
  
  # ----
  
  par(mar = c(5,4,4,0) + 0.1)
  
  plot.new()
  plot.window(xlim = range(z13.e$xy)[c(2,1)], ylim = c(194, 153))
  
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  lines(z13.e$xy, z13.e$dt)
  
  # ----
  
  par(mar = c(5,0,4,5) + 0.1)
  
  plot.new()
  plot.window(xlim = range(w17$xy), ylim = c(194, 153))
  
  axis(1)
  minorAxis(4, at.maj = ref1.maj, at.min = ref1.min, las = 1,
            labels = seq(5000, 7000,100))
  
  lines(w17$xy, w17$dt)
  
  # ----
  
  par(mar = c(5,4,4,0) + 0.1)
  
  plot.new()
  plot.window(xlim = range(z13.e$xy)[c(2,1)], ylim = c(226, 193))
  
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  lines(z13.e$xy, z13.e$dt)
  
  # ----
  
  par(mar = c(5,0,4,5) + 0.1)
  
  plot.new()
  plot.window(xlim = range(w17$xy), ylim = c(226, 193))
  
  axis(1)
  minorAxis(4, at.maj = ref2.maj, at.min = ref2.min, las = 1,
            labels = seq(7000, 9000,100))
  
  lines(w17$xy, w17$dt)
  
}


# pdfDisplay(g1(), "W21_F1", track = F, dir = getwd(), wi = 8, he = 12)


# ----

tic()

az <- extricate(z13.e$xy, z13.e$dt, nimf = 8, 
                unit_noise = "native",
                factor_noise = 150,
                comb = 500,
                speak = T)

toc()

# Gives strange warnings when duplicate dt values: make it more understandable

plot_emd(az, adapt.axis = F, track = F, dtlim = c(194,153), name = "EMD1")
# plot_emd(az, adapt.axis = F, track = F, dtlim = c(226,193), name = "EMD2")

check.emd(az, xy = z13.e$xy)

symmetry(az$m)

integrity(xy = z13.e$xy, az)

zi <- z13[1,]
zf <- z13[nrow(z13),]

(zf$age - zi$age)/(zf$dt - zi$dt)

ip1 <- inst.pulse(az)

gzc.departure(ip1)

az.age <- az
az.age$dt <- round(z13.e$age,1)
which(duplicated(az.age$dt))
check.emd(az.age, xy = z13.e$xy)

ip2 <- inst.pulse(az.age) # Slow, but has to run

gzc.departure(ip2)

peraz <- apply(1/ip2$f, 2, mean)
varaz <- apply(az$m, 2, var)[1:9]

ira <- inst.ratio(ip1, plot = F)

tinyG <- function()
{
  
  plot_ratio(ira, lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s")
  
  # plot_ratio(ir4, 
  #            lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s", 
  #            select = c("1/7", "1/8", "1/9","1/10"))
  
  plot_ratio(ira, style = "s", select = "3/5")
  
  plot_ratio(ira,  style = "s", select = "3/6")
  
  plot_ratio(ira, style = "s", select = "3/7")
  
  plot_ratio(ira,  style = "s", select = "3/8")
  
}

pdfDisplay(tinyG(), "tinyG", track = F, he = 8, dir = getwd())


gip12 <- function(){
  plot_pulse(ip1, lines = c(20,40,100,400, 1000, 2400)/55.67)
  
  plot_pulse(ip2, lines = c(20,40,100,400, 1000, 2400))
}

pdfDisplay(gip12(), name = "IF_greyscale", he = 8, track = F, dir = getwd())

pure <- az$m[,3]

amp.pure <- inst.pulse(imf = pure, dt = z13.e$dt, method = "NHT", plot = F)

g2 <- function()
{
  par(yaxs = "i", mfrow = c(1,4))
  plot.new()
  plot.window(xlim = range(z13.e$xy) - 390, ylim = c(226, 153))
  lines(pure, z13.e$dt)
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  lines(amp.pure$a, z13.e$dt, lwd = 2)
  lines(-amp.pure$a, z13.e$dt, lty = 2)
  
  plot.new()
  plot.window(xlim = range(z13$xy), ylim = c(226, 153))
  lines(z13.e$xy, z13.e$dt)
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  plot.new()
  plot.window(xlim = c(-90, 90), ylim = c(9000, 5000))
  lines(pure, z13.e$age)
  axis(1)
  minorAxis(2, at.maj = seq(5000,9000, 100), n = 10, las = 1)
  
  lines(amp.pure$a, z13.e$age, lwd = 2)
  lines(-amp.pure$a, z13.e$age, lty = 2)
  
  plot.new()
  plot.window(xlim = range(sol$tar), ylim = c(9000, 5000))
  lines(sol$tar, sol$age)
  axis(1)
  minorAxis(2, at.maj = seq(5000,9000, 100), n = 10, las = 1)
  
}

pdfDisplay(g2(), "pure", track = F, he = 25, wi = 20, dir = getwd())

# ----

zamp <- extricate(xy = amp.pure$a, ini = pure, dt = z13.e$dt, nimf = 10, 
                  sifting = 2, comb = 500,
                  unit_noise = "native",
                  factor_noise = 200,
                  speak = T)

plot_emd(zamp, name = "DEM", track = F, adapt.axis = F, dtlim = c(226,153))

check.emd(zamp, xy = amp.pure$a)

ip3 <- inst.pulse(zamp)

ir3 <- inst.ratio(ip3, lines = c(20), plot = F)

tinyR <- function()
{
  
  plot_ratio(ir3, lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s")
  
  # plot_ratio(ir4, 
  #            lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s", 
  #            select = c("1/7", "1/8", "1/9","1/10"))
  
  plot_ratio(ir3,  style = "s", select = "1/7")
  
  plot_ratio(ir3, style = "s", select = "1/8")
  
  plot_ratio(ir3,  style = "s", select = "1/9")
  
  plot_ratio(ir3, style = "s", select = "1/10")
  
}

pdfDisplay(tinyR(), "tinyR", track = F, he = 8, dir = getwd())



zamp.age <- zamp
zamp.age$dt <- round(z13.e$age,1)
# which(duplicated(zamp.age$dt))
check.emd(zamp.age, xy = amp.pure$a)
# inst.pulse(zamp.age, lines = c(20,40,100,400,1000)) # Slow, but has to run

amp100 <- zamp$m[,6]
amp400 <- zamp$m[,7]
amp1000 <- zamp$m[,8]

# ----

z13dem <- extricate(z13amp$xy, z13amp$age, nimf = 7, comb = 100, sifting = 2,
                    unit_noise = "native", factor_noise = 15,
                    speak = T)

plot_emd(z13dem, name = "Z13amp", track = F, dtlim = c(9000,5000))

check.emd(z13dem,z13amp$xy)

inst.pulse(z13dem, lines = c(100, 400,1000))

zamp100 <- z13dem$m[,4]
zamp400 <- z13dem$m[,6]
zamp1000 <- z13dem$m[,7]

ini100 <- az$m[,5]
ini400 <- az$m[,6]
ini1000 <- az$m[,7]

# ----


par(mfrow = c(1,5))

plot(amp.pure$a, z13.e$age, ylim = c(9000,5000), type = "l")
plot(z13amp$xy, z13amp$age, ylim = c(9000,5000), type = "l")

plot(amp100, z13.e$age, ylim = c(9000,5000), type = "l")
lines(zamp100 * 0.5, z13amp$age, col = "red")
lines(-ini100 * 0.25, z13.e$age, col = "darkgreen")

plot(amp400, z13.e$age, ylim = c(9000,5000), type = "l")
lines(zamp400, z13amp$age, col = "red")
lines(- ini400 * 0.20, z13.e$age, col = "darkgreen")



plot(amp1000, z13.e$age, ylim = c(9000,5000), type = "l")
lines(zamp1000, z13amp$age, col = "red")
# lines(ini1000 * 0.20, z13.e$age, col = "darkgreen")
# ----









# THE BIG ONE ------

# z13.e
# az
# amp.pure
# las
# zamp

par(yaxs = "r", mfrow = c(1,1))

apc1 <- approx.cor(sol$tar, sol$age, az$m[,3], z13.e$age)

apc1[1:3]

apc2 <- approx.cor(fil1$X1, dt2, az$m[,5], z13.e$age)

apc2[1:3]

apc3 <- approx.cor(fil2$X1, dt2, az$m[,6], z13.e$age)

apc3[1:3]

# apc4 <- approx.cor(zamp$m[,7], z13.e$age, az$m[,6], z13.e$age)
# 
# plot(zamp$m[,7], z13.e$age, type = "l")
# lines(-0.2 * az$m[,6], z13.e$age, col = "red")
# 
# apc4[1:3]

nG <- 16

bigG <- function(ylim = c(7000, 5000), n = nG)
{
  
  par(yaxs = "i", mfrow = c(1, n))
  
  rz <- rev(range(z13.e$xy))
  
  rzm <- rz - mean(rz)
  
  plot(z13.e$xy, z13.e$age, 
       ylim = ylim, xlim = c(rz[1], rz[2]), 
       type = "l", bty = "n")
  
  plot(az$m[,1], z13.e$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(az$m[,2], z13.e$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(17.9 * sol$tar, sol$age, 
       ylim = ylim, xlim = -c(rzm[1], rzm[2]),
       type = "l", axes = F)
  
  axis(1,at = 17.9 * c(-3,0,3), labels = c(-3,0,3))
  axis(2)
  
  # plot(sol$tar, -sol$age, 
  #      ylim = ylim,
  #      type = "l")
  
  plot(az$m[,3], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  lines(-amp.pure$a, z13.e$age, type = "l", lty = 1)
  
  plot(az$m[,4], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(zamp$m[,6], z13.e$age, 
       ylim = ylim, xlim = c(-rzm[1], -rzm[2]),
       type = "l", bty = "n")
  
  lines(5 * zamp$m[,6], z13.e$age, lty = 1)
  
  plot(az$m[,5], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(2000 * fil1$X1, dt2, 
       ylim = ylim, xlim = -c(rzm[1], rzm[2]),
       type = "l", axes = F,  bty = "n")
  
  axis(1, at = 2000 * c(-0.04, 0, 0.04), labels = c(-0.04, 0, 0.04))
  axis(2)
  
  # plot(fil1$X1, dt2, 
  #      ylim = ylim, xlim = c(rzm[1], rzm[2]),
  #      type = "l", axes = F,  bty = "n")
  # 
  # axis(1, at = 100 * c(-0.04, 0, 0.04), labels = c(-0.04, 0, 0.04))
  # axis(2)
  
  plot(zamp$m[,7], z13.e$age, 
       ylim = ylim, xlim = c(-rzm[1], -rzm[2]),
       type = "l", bty = "n")
  
  lines(10 * zamp$m[,7], z13.e$age, lty = 1)
  
  plot(az$m[,6], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  # lines(5 * az$m[,6], z13.e$age, lty = 2)
  
  plot(2500 * fil2$X1, dt2,
       ylim = ylim, xlim = -c(rzm[1], rzm[2]),
       type = "l", bty = "n", axes = F)
  
  axis(1,at = 2500 * c(-0.04, 0, 0.04), labels = c(-0.04, 0, 0.04))
  axis(2)
  
  # lines(5 * 2760 * las$m[,6], -las$dt, lty = 2)
  
  # plot(las$m[,6], -las$dt, 
  #      ylim = ylim, 
  #      type = "l", bty = "n")
  
  plot(az$m[,7], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(az$m[,8], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(az$m[,9], z13.e$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(az$m[,10], z13.e$age,
       ylim = ylim, xlim = c(rz[1], rz[2]), 
       type = "l", bty = "n")
  

  
}


gB <- function()
{
  bigG()
  bigG(c(9000, 7000))
}

pdfDisplay(gB(), he = 10, wi = 3*nG, name = "bigG", track = F, dir = getwd())






# Finale ----

#amp.pure
#z13.e
#z13amp
#amp
#dt2
#az
#zamp
#fil1 to 4
#z13dem

nfg <- 19

stlim <- c(-55, 55)

finG <- function(ylim = c(9000, 5000), n = nfg)
{
  
  par(yaxs = "i", mfrow = c(1, n))
  
  plot(amp.pure$a, z13.e$age, type = "l", ylim = ylim, 
       xlim = stlim + 55,
       main = "Demodulation, this paper")
  
  plot(amp, dt2, type = "l", ylim = ylim,
       xlim = range(amp),
       main = "Demodulation, Laskar et al., 2004")
  
  plot(z13amp$xy, z13amp$age, type = "l", ylim = ylim,
       xlim = stlim + 55,
       main = "Demodulation, Zeeden et al., 2013")

  
  # 100 kyr ----
  
  plot(az$m[,5], z13.e$age, type = "l", ylim = ylim,
       xlim = -stlim,
       main = "100 kyr direct, this paper")
  
  plot(zamp$m[,6], z13.e$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "100 kyr dem, this paper")
  
  plot(fil1$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "100 kyr dem, Laskar et al., 2004")
  
  plot(z13dem$m[,4], z13amp$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "100 kyr dem, Zeeden et al., 2013")
  
  
  # 400 kyr ----
  
  plot(az$m[,6], z13.e$age, type = "l", ylim = ylim,
       xlim = -stlim,
       main = "400 kyr direct, this paper")
  
  plot(zamp$m[,7], z13.e$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "400 kyr dem, this paper")
  
  plot(fil2$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "400 kyr dem, Laskar et al., 2004")
  
  plot(z13dem$m[,6], z13amp$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "400 kyr dem, Zeeden et al., 2013")
  
  # 1000 kyr ----
  
  plot(az$m[,7], z13.e$age, type = "l", ylim = ylim,
       xlim = -stlim,
       main = "1000 kyr direct, this paper")
  
  plot(zamp$m[,8], z13.e$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "1000 kyr dem, this paper")
  
  plot(fil3$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "1000 kyr dem, Laskar et al., 2004")
  
  plot(z13dem$m[,7], z13amp$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "1000 kyr dem, Zeeden et al., 2013")
  
  # 2400 kyr ----
  
  plot(az$m[,8], z13.e$age, type = "l", ylim = ylim,
       xlim = -stlim,
       main = "2400 kyr direct, this paper")
  
  plot(zamp$m[,9], z13.e$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "2400 kyr dem, this paper")
  
  plot(fil4$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "2400 kyr dem, Laskar et al., 2004")
  
  plot(z13dem$m[,8], z13amp$age, type = "l", ylim = ylim,
       xlim = stlim,
       main = "2400 kyr dem, Zeeden et al., 2013")

  
  
}

pdfDisplay(finG(), he = 8, wi = 2.5*nfg, name = "finG", track = F, dir = getwd())





