# Before running the code, make sure all packages are downloaded, and a working 
# directory is defined

# Downloading the astrochron and DecomposeR packages will be enough to download 
# the others

library(astrochron)

library(DecomposeR)
library(StratigrapheR)

# Please set a working directory ----

setwd("C:/Users/Seb/Desktop/Publications/1. EMD/ODP 926 Ceara Rise/treat")

# ----

set.seed(42)

# ----

sol <- La04_pre_obl_5_9

sol$spre <- (sol$pre - mean(sol$pre))/sd(sol$pre)
sol$sobl <- (sol$obl - mean(sol$obl))/sd(sol$obl)

sol$tar <- sol$spre - 0.5*sol$sobl

# Solution for amplitude modulation of precession ----

d2 <- La04_pre_0_20

dt2 <- d2$age
xy2 <- d2$xy - mean(d2$xy)

norm <- normalise(m = xy2, dt = dt2)

amp <- norm$a - mean(norm$a)

# ----

fil1 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/160, fhigh = 1/70, genplot = F)

fil2 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/526, fhigh = 1/285, genplot = F)

fil3 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/1400, fhigh = 1/800, genplot = F)

fil4 <- taner(data.frame(dt = dt2, xy = amp),
              flow = 1/2000, fhigh = 1/3000, genplot = F)

resi <- as.numeric(amp - fil1$X1 - fil2$X1 - fil3$X1 - fil4$X1)

mi <- as.matrix(cbind(fil1$X1, fil2$X1, fil3$X1, fil4$X1))

ampe <- as.emd(xy = amp, dt = dt2, 
               imf = mi, res = resi)

plot_emd(ampe, track = F, name = "Precession Amplitude 2",
         # adapt.axis = T,
         s = list(type = "l", lwd = 2),
         i = list(type = "l", lwd = 2) #, dtlim = c(9000, 5000)
)

check.emd(ampe, xy = amp)

# ----

sp <- respace(w17$dt, w17$xy)

aw <- extricate(sp$xy, sp$dt, nimf = 9,
                repl = 2,
                sifting = 1,
                unit_noise = "native",
                factor_noise = 50,
                comb = 100,
                bind = T,
                speak = T)

# extricate gives strange warnings when duplicate dt values: 
# make it more understandable

plot_emd(aw, adapt.axis = T, track = F, dtlim = c(226,153))

check.emd(aw, xy = sp$xy)



aw.age <- aw

aw.age$xy <- aw$xy[sp$initial]
aw.age$dt <- aw$dt[sp$initial]

aw.age$m  <- aw$m[sp$initial,,drop = F]
aw.age$repl <- aw$repl[sp$initial,,drop = F]
aw.age$mode  <- aw$mode[sp$initial,,drop = F]

check.emd(aw.age, xy = w17$xy)

ip5 <- inst.pulse(aw.age, plot = F)

gzc.departure(ip5)

ir5 <- inst.ratio(ip5, plot = F, lines = c(125/20, 400/20, 2400/20, 1000/20))

tinyM <- function()
{
  
  plot_ratio(ir5, lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s")
  
  # plot_ratio(ir4, 
  #            lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s", 
  #            select = c("1/7", "1/8", "1/9","1/10"))
  
  plot_ratio(ir5, style = "s", select = "3/5")
  
  plot_ratio(ir5,  style = "s", select = "3/6")
  
  plot_ratio(ir5, style = "s", select = "3/7")
  
  plot_ratio(ir5,  style = "s", select = "3/8")
  
}

pdfDisplay(tinyM(), "tinyM", track = F, he = 8, dir = getwd())



aw.age.real <- aw.age
aw.age.real$dt <- w17$age

# # which(duplicated(aw.age$dt))
check.emd(aw.age.real, xy = w17$xy)
ip6 <- inst.pulse(aw.age.real, plot = F)

gzc.departure(ip6)

gipX <- function(){
  plot_pulse(ip5, lines = c(20,40,125,405,1000, 2400)/55.67)
  
  plot_pulse(ip6, lines = c(20,40,125,405,1000, 2400))
}

pdfDisplay(gipX(), name = "IF_MS", he = 8, track = F, dir = getwd())


peraw <- apply(1/ip6$f, 2, mean)[1:9]
varaw <- apply(aw.age.real$m, 2, var)[1:9]

# ----

pure <- aw$m[sp$initial,3]

amp.pure <- inst.pulse(imf = pure, dt = w17$dt, method = "NHT", plot = F)


g2 <- function()
{
  par(yaxs = "i", mfrow = c(1,4))
  plot.new()
  plot.window(xlim = range(w17$xy) - 15, ylim = c(226, 153))
  lines(pure, w17$dt)
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  lines(amp.pure$a, w17$dt, lwd = 2)
  lines(-amp.pure$a, w17$dt, lty = 2)
  
  plot.new()
  plot.window(xlim = range(w17$xy), ylim = c(226, 153))
  lines(w17$xy, w17$dt)
  axis(1)
  minorAxis(2, at.maj = seq(0,640,10), n = 10, las = 1, extend = T)
  
  plot.new()
  plot.window(xlim = c(-7, 7), ylim = c(9000, 5000))
  lines(pure, w17$age)
  axis(1)
  minorAxis(2, at.maj = seq(5000,9000, 100), n = 10, las = 1)
  
  lines(amp.pure$a, w17$age, lwd = 2)
  lines(-amp.pure$a, w17$age, lty = 2)
  
  plot.new()
  plot.window(xlim = range(sol$tar), ylim = c(9000, 5000))
  lines(sol$tar, sol$age)
  axis(1)
  minorAxis(2, at.maj = seq(5000,9000, 100), n = 10, las = 1)
  
}

pdfDisplay(g2(), "pure", track = F, he = 25, wi = 20, dir = getwd())

# ----

spa <- respace(w17$dt, amp.pure$a)

wamp <- extricate(xy = spa$xy, ini = aw$m[,3], dt = spa$dt, nimf = 8, 
                  sifting = 2, comb = 100, repl = 2,
                  unit_noise = "native",
                  factor_noise = 10,
                  speak = T)

plot_emd(wamp.ori, name = "DEM", track = F, adapt.axis = F, dtlim = c(226,153))

check.emd(wamp.ori, xy = amp.pure$a)

wamp.ori <- wamp

wamp.ori$xy  <- wamp.ori$xy[spa$initial]
wamp.ori$ini <- wamp.ori$ini[spa$initial]
wamp.ori$dt  <- wamp.ori$dt[spa$initial]

wamp.ori$m     <- wamp.ori$m[spa$initial,,drop = F]
wamp.ori$repl  <- wamp.ori$repl[spa$initial,,drop = F]
wamp.ori$mode  <- wamp.ori$mode[spa$initial,,drop = F]

ip4 <- inst.pulse(wamp.ori, lines = c(20, 125, 400, 1000, 2400)/55.67)

ir4 <- inst.ratio(ip4, plot = F, style = "b")

tinyA <- function()
{
  
  plot_ratio(ir4, lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s")
  
  # plot_ratio(ir4, 
  #            lines = c(125/20, 405/20, 1000/20, 2400/20), style = "s", 
  #            select = c("1/7", "1/8", "1/9","1/10"))
  
  plot_ratio(ir4, style = "s", select = "1/7")
  
  plot_ratio(ir4,  style = "s", select = "1/8")
  
  plot_ratio(ir4, style = "s", select = "1/9")

  plot_ratio(ir4,  style = "s", select = "1/10")
  
}

pdfDisplay(tinyA(), "tinyA", track = F, he = 8, dir = getwd())



wamp.age <- wamp

wamp.age$xy <- wamp$xy[sp$initial]
wamp.age$ini <- wamp$ini[sp$initial]

wamp.age$m  <- wamp$m[sp$initial,,drop = F]
wamp.age$repl <- wamp$repl[sp$initial,,drop = F]
wamp.age$mode  <- wamp$mode[sp$initial,,drop = F]

wamp.age$dt <- w17$age

# which(duplicated(zamp.age$dt))
check.emd(wamp.age, xy = as.vector(amp.pure$a))
inst.pulse(wamp.age, lines = c(20,40,100,400,1000))

# ----

amp100 <- wamp$m[sp$initial,6]
amp400 <- wamp$m[sp$initial,7]
amp1000 <- wamp$m[sp$initial,8]

# ----

sc97dem <- extricate(sc97amp$xy, sc97amp$age, nimf = 6, repl = 4,
                     comb = 100, sifting = 2,
                    unit_noise = "native", factor_noise = 15,
                    speak = T)

plot_emd(sc97dem, name = "sc97amp", track = F, dtlim = c(9000,5000))

check.emd(sc97dem,sc97amp$xy)

inst.pulse(sc97dem, lines = c(100, 400))

wamp100 <- sc97dem$m[,2]
wamp400 <- sc97dem$m[,4]

# ini100 <- az$m[,5]
# ini400 <- az$m[,6]

# ----


par(mfrow = c(1,4))

plot(amp.pure$a, w17$age, ylim = c(9000,5000), type = "l")
plot(sc97amp$xy, sc97amp$age, ylim = c(9000,5000), type = "l")

plot(amp100, w17$age, ylim = c(9000,5000), type = "l")
lines(wamp100, sc97amp$age, col = "red")
# lines(-ini100 * 0.25, w17$age, col = "darkgreen")

plot(amp400, w17$age, ylim = c(9000,5000), type = "l")
lines(wamp400, sc97amp$age, col = "red")
# lines(- ini400 * 0.20, w17$age, col = "darkgreen")

# ----




# THE BIG 2 ------

# z13.e     in w17
# az        in aw.age
# amp.pure
# las
# zamp      in wamp.age

par(yaxs = "r", mfrow = c(1,1))

apc1 <- approx.cor(sol$tar, sol$age, aw.age$m[,3], w17$age)

apc1[1:3]

apc2 <- approx.cor(fil1$X1, dt2, aw.age$m[,5], w17$age)

apc2[1:3]

apc3 <- approx.cor(fil2$X1, dt2, aw.age$m[,6], w17$age)

apc3[1:3]

# apc4 <- approx.cor(zamp$m[,7], z13.e$age, az$m[,6], z13.e$age)
# 
# plot(zamp$m[,7], z13.e$age, type = "l")
# lines(-0.2 * az$m[,6], z13.e$age, col = "red")
# 
# apc4[1:3]

nM <- 16

ylim <- c(7000, 5000)
n    <- nM

bigM <- function(ylim = c(7000, 5000), n = nM)
{
  
  par(yaxs = "i", mfrow = c(1, n))
  
  rz <- range(w17$xy)
  
  rzm <- rz - mean(rz)
  
  plot(w17$xy, w17$age, 
       ylim = ylim, xlim = c(rz[1], rz[2]), 
       type = "l", bty = "n")
  
  plot(aw.age$m[,1], w17$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(aw.age$m[,2], w17$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(sol$tar, sol$age, 
       ylim = ylim, 
       xlim = c(rzm[1], rzm[2]),
       type = "l", axes = F)
  
  axis(1)
  axis(2)
  
  # plot(sol$tar, -sol$age, 
  #      ylim = ylim,
  #      type = "l")
  
  plot(aw.age$m[,3], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  lines(amp.pure$a, w17$age, type = "l", lty = 1)
  
  plot(aw.age$m[,4], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(wamp.age$m[,6], w17$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]),
       type = "l", bty = "n")
  
  lines(4 * wamp.age$m[,6], w17$age, lty = 1)
  
  plot(aw.age$m[,5], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(100 * fil1$X1, dt2, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]),
       type = "l", axes = F,  bty = "n")
  
  axis(1, at = 100 * c(-0.04, 0, 0.04), labels = c(-0.04, 0, 0.04))
  axis(2)
  
  plot(wamp.age$m[,7], w17$age, 
       ylim = ylim, xlim = c(rzm[1], rzm[2]),
       type = "l", bty = "n")
  
  lines(4 * wamp.age$m[,7], w17$age, lty = 1)
  
  plot(aw.age$m[,6], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  # lines(5 * aw.age$m[,6], w17$age, lty = 2)
  
  plot(200 * fil2$X1, dt2, 
       ylim = ylim, 
       xlim = c(rzm[1], rzm[2]),
       type = "l", bty = "n", axes = F)
  
  axis(1, at = 200 * c(-0.02, 0, 0.02), labels = c(-0.02, 0, 0.02))
  axis(2)
  
  # lines(5 * 2760 * las$m[,6], -las$dt, lty = 2)
  
  # plot(las$m[,6], -las$dt, 
  #      ylim = ylim, 
  #      type = "l", bty = "n")
  
  plot(aw.age$m[,7], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(aw.age$m[,8], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(aw.age$m[,9], w17$age,
       ylim = ylim, xlim = c(rzm[1], rzm[2]), 
       type = "l", bty = "n")
  
  plot(aw.age$m[,10], w17$age,
       ylim = ylim, xlim = c(rz[1], rz[2]), 
       type = "l", bty = "n")
  
}


gM <- function()
{
  bigM()
  bigM(c(9000, 7000))
}

pdfDisplay(gM(), he = 10, wi = 3*nM, name = "bigM", track = F, dir = getwd())







# Finale ----

#amp.pure
#w17
#sc97
#amp
#dt2
#aw.age
#wamp.age
#fil1 to 4
#sc97amp

nfm <- 19

finM <- function(ylim = c(9000, 5000), n = nfm)
{
  
  par(yaxs = "i", mfrow = c(1, n))

  plot(amp.pure$a, w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]) - range(aw.age$m[,5])[1],
       main = "Dem, this paper")
  
  plot(amp, dt2, type = "l", ylim = ylim,
       xlim = range(amp),
       main = "Dem, Laskar et al., 2004")

  plot(sc97amp$xy, sc97amp$age, type = "l", ylim = ylim,
       xlim = range(sc97amp$xy),
       main = "Dem, S&C 1997")


  # 100 kyr ----

  plot(aw.age$m[,5], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "100 kyr direct, this paper")

  plot(wamp.age$m[,6], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "100 kyr dem, this paper")

  plot(fil1$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "100 kyr dem, Laskar et al., 2004")

  plot(sc97dem$m[,2], sc97amp$age, type = "l", ylim = ylim,
       xlim = range(sc97amp$xy) - mean(range(sc97amp$xy)),
       main = "100 kyr dem, S&C 1997")


  # 400 kyr ----
  
  plot(aw.age$m[,6], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "400 kyr direct, this paper")
  
  plot(wamp.age$m[,7], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "400 kyr dem, this paper")
  
  plot(fil2$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "400 kyr dem, Laskar et al., 2004")
  
  plot(sc97dem$m[,4], sc97amp$age, type = "l", ylim = ylim,
       xlim = range(sc97amp$xy) - mean(range(sc97amp$xy)),
       main = "400 kyr dem, S&C 1997")

  
  # 1000 kyr ----
  
  plot(aw.age$m[,7], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "1000 kyr direct, this paper")
  
  plot(wamp.age$m[,8], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "1000 kyr dem, this paper")
  
  plot(fil3$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "1000 kyr dem, Laskar et al., 2004")
  
  plot(sc97dem$m[,5], sc97amp$age, type = "l", ylim = ylim,
       xlim = range(sc97amp$xy) - mean(range(sc97amp$xy)),
       main = "1000 kyr dem, S&C 1997")
  
  
  # 2400 kyr ----

  plot(aw.age$m[,8], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "2400 kyr direct, this paper")
  
  plot(wamp.age$m[,9], w17$age, type = "l", ylim = ylim,
       xlim = range(aw.age$m[,5]),
       main = "2400 kyr dem, this paper")
  
  plot(fil4$X1, dt2, type = "l", ylim = ylim,
       xlim = range(amp) - mean(range(amp)),
       main = "2400 kyr dem, Laskar et al., 2004")
  
  plot(sc97dem$m[,6], sc97amp$age, type = "l", ylim = ylim,
       xlim = range(sc97amp$xy) - mean(range(sc97amp$xy)),
       main = "2400 kyr dem, S&C 1997")
  # 
  
  
}

pdfDisplay(finM(), he = 8, wi = 2.5*nfm, name = "finM", track = F, dir = getwd())



